@@ -45,7 +45,7 @@ char saz2[][5] = {"","","",""}; //
 char sahz[][5] = {"|","p","|","|"};
 
 // :make邹悹 Fꂽ
-char go_a[][11] = {"Ȃ","","","","","Ȃ","","˂"}; // 8
+char go_a[][11] = {"Ȃ","","","","","Ȃ","","˂",""}; // 9
 //  ȂȂȂ
 char go_i[][11] = {"܂","","","","܂",
                    "","܂","ςȂ","","₷",
@@ -446,7 +446,7 @@ char *mode, *jpw;
 int ln;
 {
   int i, yn = 0;
-            for(i = 0; i < 8; i++){ // go_a
+            for(i = 0; i < 9; i++){ // go_a
               if(strncmp(wdw+ln-2, go_a[i], strlen(go_a[i])) == 0){
 	        ptinsert(wdw+ln-2, "");
  if(Dbg == 'Y') fprintf(dbg, "--- %sKatsu go_a --- jpw = %s wdw = %s \n", mode, jpw, wdw);
@@ -550,7 +550,7 @@ char *jpw;
 	  }
 	}
         if(strncmp(wdw+ln-2, godan_mize[j], 2) == 0){ // 
-          for(i = 0; i < 8; i++){ // go_a
+          for(i = 0; i < 9; i++){ // go_a
             if(strncmp(wdw+ln, go_a[i], strlen(go_a[i])) == 0){
 	      ptreplace(wdw+ln-2, 2, godan_syuu[j]);
  if(Dbg == 'Y') fprintf(dbg, "--- godanKatsu go_a --- jpw = %s wdw = %s \n", jpw, wdw);
@@ -763,67 +763,6 @@ char *jpw, *hinsi;
 }
 
 
-
-char *t8u = ",n荇,𑈂,݂,Y,,ь"; // 14%
-char *t8tu = "";
-char *t6ru = "؂,Ԃ,g,܂,܂,,,Â,܂,~܂,܂,͒m,,͂܂,߂,ڂ,߂,,,ǂ,,ւ,͂,,h"; // 15%
-char *t6u = "ɂ,Ԉ,,,,"; // 16%
-char *_6ru = ",,܂,h点,݂,,,ӂ邦,Ƃǂ,܂,܂,Ȃ,d,ڂ₯,ӂ,Ƃ,,m点,͂,,,肪,,o},ӂ,킹,ɔ"; // 17%
-char *t4u = "ǂ,z,,,,j,,"; // 19%
-char *t4tu = ",,ۂ";
-char *t4ru = ",@,,ӂ,f,,ł,,l,ւ,~,,,,i,"; // 23%
-char *_4ru = "},,f,,,ウ,,L,,,,悹,O,i,x,,,G,F,,f,,A,,,,,,C,݂,,,,,ɂ,,n,؂,ς,~,͂,ł,,,nQ,l,q,,,N,,f,L,,,o,Y,u,~,,,[,,̂,,؂,,,,߂,,͂,ł,k,,,,Ђ,,,^,,,ς,΂,,,,т"; // 24% rare4ru
- char *i6ku = "Q,CÂ";
- char *i4ku = ",,,J,킢,,,,u,,,炢,,~,w,"; // 27%
-
- char *n8mu = ",,ӂ,قق,"; // 29%
- char *i6gu = "ӂ,";
- char *n6mu = ",,,c,ɂ"; // 29%
- char *n4bu = "I"; // 30%
- char *i4gu = "";
- char *n4mu = "҂,j,,,,ς"; // 31%
-char *_2ru = "o"; // 32%
-char *mize8syuu = ",l,藧,䂩";
-char *mize6syuu = "CÂ,Â,܂"; // 38%
-char *mize4syuu = ",͂,y,,u,ʂ,m,,,,Ă,,؂,v,,i,,s,,,Ȃ,,,,,"; // 38%
-char *i8u = "o";
-char *i6u = "炢"; // 42%
-char *i4u = "],";
-char *masu8_ru = "";
-char *masu4_ru = "}"; // 44%
-char *masu8syuu = "SȂ,󂯎,~葱,";
-char *masu6syuu = "I,,̂,N,オ,̂,o,g,܂,ł,,߂Â,L,ƂȂ,قȂ"; // 45%
-char *masu4syuu = "͂,v,,,Ⴂ,,,,,,s,ʂ,,r,,,,,,,,Ȃ,,,,,J,,,,,o,,Ă,n,m,,,,i,"; // 45%
-char *kate4syuu = ",,,Ȃ,,,],,ǂ,g,,v,b,,s,A,,,,"; // 53%
-char *rare8ru = "グ,炦,,艺,z,˂,Ƃ";
-char *rare6ru = "т,Y,܂Ƃ,ł";
-//char *rare4ru = "u,~,Y,,,F,";
-char *rare2ru = ",,,,,,,,,f"; // 54%
-// sahen
-char *sit8suru = ",y݂,傯,lς,Rc,т,"; // 59%
-char *sit6suru = "΂,Ƃ,Z,Sn,ɑ؍,؂,}~,菵,d,No,グ";
-char *sit4suru = ",J,^],A,ӌ,,,,U,],ǔF,t,ቺ,C,@,x,N,xo,,|,,,┑,,W,,,Mʕ,z,,Az,J,,Ǘ,g,ے,,A,ӎ,˗,AC,p,we,S,,LO,,NU,Ti,ʊw,n,\\,㋞,,S,،,R,S,C,J,,,ϐg,̏,Sz,T,,˓,j,M,,,i,,,ڂ,,,^p,Ɨ"; // 59%
-char *sit2suru = ",,"; // 62%
-char *sit8su = "s,D,";
-char *sit6su = "vo,,v";
-char *sit4su = ",,ʂ,߂,Ƃ,,,y,";
-char *sit2su = "\\,,B,,,@,w,,,k,,,";
-char *s8su = "Ăs";
-char *s6su = ",g,ߏo,J";
-char *s4su = ",N,߂,,n,,,Ƃ,,܂,,"; // 71%
-char *s2su = "\\,C,B,L,E,,"; // -
-char *s6suru = "菵,_,ɕ\\";
-char *s4suru = "k,B,,K,̑,,,L,,z,䖝,,F,蒅,,I,ᔻ,{,,|,,o,f,,ړ,K,_,,\\,n,,,,,֒,\\,o,,Ζ,Mp,,,gU,\\,,̎^,U,oc,Ǘ,G,,"; // 72%
-// keiyo
-
-char *ku6i = "₽,F,邭,,ʔ,傫,낤,,V"; // 75%
-char *ku4i = ",,,y,R,,ł,"; // 76%
- char *katta6i = "r,ڐV,iD,r"; // 76%
- char *katta2i = "";
-
-
-
-
 int desumasu_ck()
 {
     int  i;
