@@ -10,7 +10,7 @@ extern char sj[], oj[], vr[], sz[], oz[], vz[], pst[], Dbg, LOG;
 extern char aj[WordNumb][YakugoMax][JWordLen], az[WordNumb][YakugoMax][ZokuLen],
 	en[WordNumb][SentLen], csq[WordNumb];
 char caj[YakugoMax][JWordLen], caz[YakugoMax][ZokuLen];
-char ptek[95], dumt[95];
+char ptek[195], dumt[195];
 //int  comma;
 //extern char *dir;
 
@@ -32,7 +32,7 @@ tekyk(){
 	    strcpy(caj[i], aj[wc][i]);	strcpy(caz[i], az[wc][i]);
 	  }
 	  cnb = --i;	pwct = 0;	j = 1;
-	  ptek[92] = '\0';
+	  ptek[192] = '\0';
 	  while(cnb >= 1 && j <= cnb && pwct == 0){
 	    c0 = caj[0][0];	j = 1;
 	    while(j <= cnb){
@@ -54,7 +54,7 @@ tekyk(){
 	      if((tekpt = fopen(Tekiyakufile, "r")) == '\0'){
 		printf("Teki I[vł܂łB");	exit(1);
 	      }
-	      while((f=(int)fgets(ptek, 92, tekpt))){ ct = 0;
+	      while((f=(int)fgets(ptek, 192, tekpt))){ ct = 0;
 		ptek[strlen(ptek)-1] = '\0';
 		tcd[0] = ptek[0];	tcd[1] = ptek[1];	tcd[2] = '\0';
 		if(strcmp(cd, tcd) > 0) continue;
@@ -166,10 +166,10 @@ int  *comma;
       if(strcmp(en[i], "and") == 0 || strcmp(en[i], ",") == 0){
 	*comma = i;
 	if(strcmp(en[i-1], ",") == 0) (*comma)--;
+ if(Dbg == 'Y') fprintf(dbg, "--- fukuCk --- comma = %d \n", *comma);
 	break;
       }
     }
- if(Dbg == 'Y') fprintf(dbg, "--- fukuCk --- comma = %d \n", *comma);
     if(*comma == 0){ ct = -1;	return; }
     for(i = *comma+1; i <= wnb; i++){
       if(aj[i][0][0] == '3' && (aj[i][1][0] == '\0' || aj[i][1][0] == '3'))
@@ -569,12 +569,14 @@ char *pj;
 	for(i = wc-3; i >= 0; i--)
 	  if(strstr(aj[i][0], eu)){ tsta = i-1;	break; }
       left(cq1, csq, wc);
-      j9 = instrc(cq1, '9');	j3 = instrc(csq, '3');
+      j9 = instrc(cq1, '9');	j9=0; // 15/12/24 ڑ(and,or,..)
+      j3 = instrc(csq, '3');
       j33 = ninstrc(j9+1, csq, '3');
       if(j3 > 0 && j9 > j3 && j33 > 0){
 	if(j9 == j3+1 && j33 == j9+1 && en[j3-1] == en[j9]) tend = 0;
 	else tend = j9-1;
       }
+ // if(Dbg == 'Y') fprintf(dbg, "--- eqazck --- tst = %s tend = %d \n", tst, tend);
     }
     else {
       tend = wc+1;	tsta = wnb;
@@ -585,7 +587,7 @@ char *pj;
 	  if(aj[i][0][0] == '#'){ tsta = i-1;	break; }
       }
       right(csq, cq1, strlen(csq)-wc-1);
-      j9 = instrc(cq1, '9');
+      j9 = instrc(cq1, '9');  j9 = 0; // 15/12/24 ڑ(and,or,..)
       j00 = ninstrc(j9+1, cq1, '0');
       j3 = instrc(csq, '3');
       j33 = ninstrc(j9+1, cq1, '3');
@@ -610,6 +612,7 @@ char *pj;
       }
       else{
 	if(*(pj-2) == 'E'){
+ // if(Dbg == 'Y') fprintf(dbg, "--- eqazck --- tst = %s cq1= %s j9= %d \n", tst, cq1, j9);
 	  eneq(tst, i);
 	  if(ct == 1) goto OKEZ;
 	  else{ ct = -1;	goto NXT3; }
@@ -846,7 +849,8 @@ char tcd[];
 	}
 	cnb = --i;
 	if(!strstr(caj[0], "(SŁI ptek = ...")){
-	  strcat(caj[0], "(SŁI ptek = ...");	ln = strlen(ptek);
+	  strcat(caj[0], "(SŁI ptek = ...");
+	  ln = strlen(ptek);
 	  if(ln <= 8) strcat(caj[0], ptek);
 	  else strcat(caj[0], ptek+ln-8);
 	  strcat(caj[0], ")");
